@@ -1,4 +1,5 @@
-import common
+from tests import common
+from hglib.util import b
 
 class test_bookmarks(common.basetest):
     def test_empty(self):
@@ -6,18 +7,18 @@ class test_bookmarks(common.basetest):
 
     def test_basic(self):
         self.append('a', 'a')
-        rev0, node0 = self.client.commit('first', addremove=True)
+        rev0, node0 = self.client.commit(b('first'), addremove=True)
         self.append('a', 'a')
-        rev1, node1 = self.client.commit('second')
+        rev1, node1 = self.client.commit(b('second'))
 
-        self.client.bookmark('zero', rev0)
+        self.client.bookmark(b('zero'), rev0)
         self.assertEquals(self.client.bookmarks(),
-                          ([('zero', rev0, node0[:12])], -1))
+                          ([(b('zero'), rev0, node0[:12])], -1))
 
-        self.client.bookmark('one', rev1)
+        self.client.bookmark(b('one'), rev1)
         self.assertEquals(self.client.bookmarks()[0],
-                          [('one', rev1, node1[:12]),
-                           ('zero', rev0, node0[:12])])
+                          [(b('one'), rev1, node1[:12]),
+                           (b('zero'), rev0, node0[:12])])
 
     #def test_spaces(self):
     #    self.client.bookmark('s pace', self.rev0)
