@@ -27,6 +27,13 @@ class test_log(common.basetest):
         self.assertTrue(len(revs) == 1)
         self.assertEquals(revs[0].rev, b('0'))
 
+    def test_empty_short_option(self):
+        self.append('foobar', 'foobar')
+        self.client.commit(b('first'), addremove=True)
+        revs = self.client.log(keyword=b(''), files=[b('foobar')])
+        self.assertTrue(len(revs) == 1)
+        self.assertEquals(revs[0].rev, b('0'))
+
     # def test_errors(self):
     #     self.assertRaisesRegexp(CommandError, 'abort: unknown revision',
     #                             self.client.log, 'foo')
