@@ -1,13 +1,14 @@
-import common
+from tests import common
 from hglib import error
+from hglib.util import b, strtobytes
 
 class test_update(common.basetest):
     def setUp(self):
         common.basetest.setUp(self)
         self.append('a', 'a')
-        self.rev0, self.node0 = self.client.commit('first', addremove=True)
+        self.rev0, self.node0 = self.client.commit(b('first'), addremove=True)
         self.append('a', 'a')
-        self.rev1, self.node1 = self.client.commit('second')
+        self.rev1, self.node1 = self.client.commit(b('second'))
 
     def test_basic(self):
         u, m, r, ur = self.client.update(self.rev0)
@@ -24,24 +25,24 @@ class test_update(common.basetest):
         self.assertEquals(m, 0)
         self.assertEquals(r, 0)
         self.assertEquals(ur, 1)
-        self.assertTrue(('M', 'a') in self.client.status())
+        self.assertTrue((b('M'), b('a')) in self.client.status())
 
     def test_merge(self):
         self.append('a', '\n\n\n\nb')
-        rev2, node2 = self.client.commit('third')
+        rev2, node2 = self.client.commit(b('third'))
         self.append('a', 'b')
-        self.client.commit('fourth')
+        self.client.commit(b('fourth'))
         self.client.update(rev2)
         old = open('a').read()
         f = open('a', 'wb')
-        f.write('a' + old)
+        f.write(b('a') + old.encode('latin-1'))
         f.close()
         u, m, r, ur = self.client.update()
         self.assertEquals(u, 0)
         self.assertEquals(m, 1)
         self.assertEquals(r, 0)
         self.assertEquals(ur, 0)
-        self.assertEquals(self.client.status(), [('M', 'a')])
+        self.assertEquals(self.client.status(), [(b('M'), b('a'))])
 
     def test_tip(self):
         self.client.update(self.rev0)
@@ -51,7 +52,7 @@ class test_update(common.basetest):
 
         self.client.update(self.rev0)
         self.append('a', 'b')
-        rev2, node2 = self.client.commit('new head')
+        rev2, node2 = self.client.commit(b('new head'))
         self.client.update(self.rev0)
 
         self.client.update()
@@ -76,20 +77,22 @@ class test_update(common.basetest):
         f.close()
         self.test_basic()
 
-    def test_largefiles(self):
+    def disabled_largefiles(self):
+        # we don't run reposetup after a session has started, so this
+        # test is broken
         import os
         f = open('.hg/hgrc', 'a')
         f.write('[extensions]\nlargefiles=\n')
         f.close()
         self.append('b', 'a')
         try:
-            self.client.rawcommand(['add', 'b', '--large'])
+            self.client.rawcommand([b('add'), b('b'), b('--large')])
         except error.CommandError:
             return
 
-        rev2, node2 = self.client.commit('third')
+        rev2, node2 = self.client.commit(b('third'))
         # Go back to 0
-        self.client.rawcommand(['update', str(self.rev0)],
+        self.client.rawcommand([b('update'), strtobytes(self.rev0)],
                                 # Keep the 'changed' version
                                prompt=lambda s, d: 'c\n')
         u, m, r, ur = self.client.update(rev2, clean=True)
